summaryrefslogtreecommitdiffstats
path: root/tdecore/knotifyclient.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tdecore/knotifyclient.cpp')
-rw-r--r--tdecore/knotifyclient.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/tdecore/knotifyclient.cpp b/tdecore/knotifyclient.cpp
index 1eb4b42fb..eaac81754 100644
--- a/tdecore/knotifyclient.cpp
+++ b/tdecore/knotifyclient.cpp
@@ -74,14 +74,14 @@ static int sendNotifyEvent(const TQString &message, const TQString &text,
int present, int level, const TQString &sound,
const TQString &file, int winId )
{
- if (!kapp) return 0;
+ if (!tdeApp) return 0;
// ensure tray icon is shown and positioned before sending event to notification daemon
#ifdef TQ_WS_X11
XFlush(tqt_xdisplay());
#endif
- DCOPClient *client=kapp->dcopClient();
+ DCOPClient *client=tdeApp->dcopClient();
if (!client->isAttached())
{
client->attach();
@@ -94,7 +94,7 @@ static int sendNotifyEvent(const TQString &message, const TQString &text,
if( canAvoidStartupEvent( message, appname, present ))
return -1; // done "successfully" - there will be no event presentation
- int uniqueId = kMax( 1, kapp->random() ); // must not be 0 -- means failure!
+ int uniqueId = kMax( 1, tdeApp->random() ); // must not be 0 -- means failure!
// knotify daemon needs toplevel window
TQWidget* widget = TQWidget::find( (WId)winId );
@@ -238,7 +238,7 @@ TQString KNotifyClient::getDefaultFile(const TQString &eventname, int present)
bool KNotifyClient::startDaemon()
{
static bool firstTry = true;
- if (!kapp->dcopClient()->isApplicationRegistered(daemonName)) {
+ if (!tdeApp->dcopClient()->isApplicationRegistered(daemonName)) {
if( firstTry ) {
firstTry = false;
return TDEApplication::startServiceByDesktopName(daemonName) == 0;
@@ -251,12 +251,12 @@ bool KNotifyClient::startDaemon()
void KNotifyClient::beep(const TQString& reason)
{
- if ( !kapp || KNotifyClient::Instance::currentInstance()->useSystemBell() ) {
+ if ( !tdeApp || KNotifyClient::Instance::currentInstance()->useSystemBell() ) {
TQApplication::beep();
return;
}
- DCOPClient *client=kapp->dcopClient();
+ DCOPClient *client=tdeApp->dcopClient();
if (!client->isAttached())
{
client->attach();
@@ -307,7 +307,7 @@ public:
{
if (m_instances.isEmpty())
{
- m_defaultInstance = new Instance(kapp);
+ m_defaultInstance = new Instance(tdeApp);
}
return m_instances.top();
}
@@ -360,7 +360,7 @@ bool KNotifyClient::Instance::useSystemBell() const
// static methods
// We always return a valid KNotifyClient::Instance here. If no special one
// is available, we have a default-instance with kapp as TDEInstance.
// We make sure to always have that default-instance in the stack, because
// the stack might have gotten cleared in the destructor.
// We can't use QPtrStack::setAutoDelete( true ), because no instance besides
@@ -360,7 +360,7 @@ bool KNotifyClient::Instance::useSystemBell() const
// static methods
// We always return a valid KNotifyClient::Instance here. If no special one
-// is available, we have a default-instance with kapp as TDEInstance.
+// is available, we have a default-instance with tdeApp as TDEInstance.
// We make sure to always have that default-instance in the stack, because
// the stack might have gotten cleared in the destructor.